=============
extract-pages
=============

.. image:: https://img.shields.io/travis/mrakitin/extract-pages.svg
        :target: https://travis-ci.org/mrakitin/extract-pages

.. image:: https://img.shields.io/pypi/v/extract-pages.svg
        :target: https://pypi.python.org/pypi/extract-pages


Extract and combine pages from multiple pdf files

* Free software: 3-clause BSD license
* Documentation: https://mrakitin.github.io/extract-pages.

Features
--------

* TODO
